==> jc-1.4.0.tar.gz: soot/jimple/JimpleBody.h <==
// public class soot.jimple.JimpleBody

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 197add2ebd99cc14 soot_jimple_JimpleBody
// @dep_class a93f9b2adf19105a soot_jimple_StmtBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_StmtBody

#include "soot/jimple/StmtBody.h"

#ifndef _JC_soot_jimple_JimpleBody_H_
#define _JC_soot_jimple_JimpleBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_JimpleBody$sub_refs	_jc_soot_jimple_JimpleBody$sub_refs;
typedef struct _jc_soot_jimple_JimpleBody$sub_nonrefs	_jc_soot_jimple_JimpleBody$sub_nonrefs;
typedef struct _jc_soot_jimple_JimpleBody$refs	_jc_soot_jimple_JimpleBody$refs;
typedef struct _jc_soot_jimple_JimpleBody$nonrefs	_jc_soot_jimple_JimpleBody$nonrefs;
typedef struct _jc_soot_jimple_JimpleBody$object	_jc_soot_jimple_JimpleBody$object;

typedef const struct _jc_soot_jimple_JimpleBody$vmethods	_jc_soot_jimple_JimpleBody$vmethods;
typedef const struct _jc_soot_jimple_JimpleBody$vtable	_jc_soot_jimple_JimpleBody$vtable;
typedef const struct _jc_soot_jimple_JimpleBody$vtype	_jc_soot_jimple_JimpleBody$vtype;

// Constructors
extern void _jc_soot_jimple_JimpleBody$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
extern void _jc_soot_jimple_JimpleBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_JimpleBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
extern struct _jc_object *_jc_soot_jimple_JimpleBody$method$getFirstNonIdentityStmt$65a0fb2cf2c61772(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
extern void _jc_soot_jimple_JimpleBody$method$insertIdentityStmts$a936808f2be082e2(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
extern void _jc_soot_jimple_JimpleBody$method$validate$2e306121ab937fa0(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$getFirstNonIdentityStmt$65a0fb2cf2c61772;
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$insertIdentityStmts$a936808f2be082e2;
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$validate$2e306121ab937fa0;

// Virtual methods structure
struct _jc_soot_jimple_JimpleBody$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
	struct _jc_object	*(*getFirstNonIdentityStmt$65a0fb2cf2c61772)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
	void	(*insertIdentityStmts$a936808f2be082e2)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
	void	(*validate$2e306121ab937fa0)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *);
};

// Vtable
struct _jc_soot_jimple_JimpleBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_jimple_StmtBody$vmethods	soot_jimple_StmtBody;
	_jc_soot_jimple_JimpleBody$vmethods	soot_jimple_JimpleBody;
};

// Vtype
struct _jc_soot_jimple_JimpleBody$vtype {
	_jc_type			type;
	_jc_soot_jimple_JimpleBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JimpleBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_JimpleBody$refs {
    _jc_soot_jimple_JimpleBody$sub_refs	soot_jimple_JimpleBody;
    _jc_soot_jimple_StmtBody$sub_refs	soot_jimple_StmtBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JimpleBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JimpleBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_jimple_StmtBody$sub_nonrefs	soot_jimple_StmtBody;
    _jc_soot_jimple_JimpleBody$sub_nonrefs	soot_jimple_JimpleBody;
};

// Object instance structure
struct _jc_soot_jimple_JimpleBody$object {
	_jc_soot_jimple_JimpleBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JimpleBody$vtype	*vtype;
	_jc_soot_jimple_JimpleBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JimpleBody$vtype _jc_soot_jimple_JimpleBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JimpleBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JimpleBody$class_object;

#endif	/* _JC_soot_jimple_JimpleBody_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/JimpleBody.h <==
// public class soot.jimple.JimpleBody

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 197add2ebd99cc14 soot_jimple_JimpleBody
// @dep_class a93f9b2adf19105a soot_jimple_StmtBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_StmtBody

#include "soot/jimple/StmtBody.h"

#ifndef _JC_soot_jimple_JimpleBody_H_
#define _JC_soot_jimple_JimpleBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_JimpleBody$sub_refs	_jc_soot_jimple_JimpleBody$sub_refs;
typedef struct _jc_soot_jimple_JimpleBody$sub_nonrefs	_jc_soot_jimple_JimpleBody$sub_nonrefs;
typedef struct _jc_soot_jimple_JimpleBody$refs	_jc_soot_jimple_JimpleBody$refs;
typedef struct _jc_soot_jimple_JimpleBody$nonrefs	_jc_soot_jimple_JimpleBody$nonrefs;
typedef struct _jc_soot_jimple_JimpleBody$object	_jc_soot_jimple_JimpleBody$object;

typedef const struct _jc_soot_jimple_JimpleBody$vmethods	_jc_soot_jimple_JimpleBody$vmethods;
typedef const struct _jc_soot_jimple_JimpleBody$vtable	_jc_soot_jimple_JimpleBody$vtable;
typedef const struct _jc_soot_jimple_JimpleBody$vtype	_jc_soot_jimple_JimpleBody$vtype;

// Constructors
extern void _jc_soot_jimple_JimpleBody$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JimpleBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_JimpleBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_JimpleBody$method$getFirstNonIdentityStmt$65a0fb2cf2c61772(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JimpleBody$method$insertIdentityStmts$a936808f2be082e2(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JimpleBody$method$validate$2e306121ab937fa0(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$getFirstNonIdentityStmt$65a0fb2cf2c61772;
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$insertIdentityStmts$a936808f2be082e2;
extern _jc_method _jc_soot_jimple_JimpleBody$method_info$validate$2e306121ab937fa0;

// Virtual methods structure
struct _jc_soot_jimple_JimpleBody$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getFirstNonIdentityStmt$65a0fb2cf2c61772)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
	void	(*insertIdentityStmts$a936808f2be082e2)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
	void	(*validate$2e306121ab937fa0)(_jc_env *, struct _jc_soot_jimple_JimpleBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_JimpleBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_jimple_StmtBody$vmethods	soot_jimple_StmtBody;
	_jc_soot_jimple_JimpleBody$vmethods	soot_jimple_JimpleBody;
};

// Vtype
struct _jc_soot_jimple_JimpleBody$vtype {
	_jc_type			type;
	_jc_soot_jimple_JimpleBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JimpleBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_JimpleBody$refs {
    _jc_soot_jimple_JimpleBody$sub_refs	soot_jimple_JimpleBody;
    _jc_soot_jimple_StmtBody$sub_refs	soot_jimple_StmtBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JimpleBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JimpleBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_jimple_StmtBody$sub_nonrefs	soot_jimple_StmtBody;
    _jc_soot_jimple_JimpleBody$sub_nonrefs	soot_jimple_JimpleBody;
};

// Object instance structure
struct _jc_soot_jimple_JimpleBody$object {
	_jc_soot_jimple_JimpleBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JimpleBody$vtype	*vtype;
	_jc_soot_jimple_JimpleBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JimpleBody$vtype _jc_soot_jimple_JimpleBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JimpleBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JimpleBody$class_object;

#endif	/* _JC_soot_jimple_JimpleBody_H_ */
